Project::OSiRiON - Git repositories
Project::OSiRiON
News . About . Screenshots . Downloads . Forum . Wiki . Tracker . Git
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'src/osirion.cc')
-rw-r--r--src/osirion.cc7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/osirion.cc b/src/osirion.cc
index 696104f..6fa2eb3 100644
--- a/src/osirion.cc
+++ b/src/osirion.cc
@@ -9,12 +9,13 @@
int main(int count, char **arguments)
{
- // preload the game object
- game::Game *game = new game::Game();
+ // preload the game module
+ core::Module::load(new game::Game());
client::main(count, arguments);
- game = 0; // prevents variable not used warning
+ // unload the game module
+ core::Module::unload();
return 0;
}